@@ -1,9 +1,8 @@
 /*
  * $RCSfile: server_udp.c,v $
  *
- * Copyright (c) 1999-2005. Christian Heller. All rights reserved.
+ * Copyright (c) 1999-2005. Christian Heller and the CYBOP developers.
  *
- * This software is published under the GPL GNU General Public License.
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
  * as published by the Free Software Foundation; either version 2
@@ -23,7 +22,7 @@
  *
  * This file handles a server UDP socket.
  *
- * @version $Revision: 1.4 $ $Date: 2005/01/10 14:46:33 $ $Author: christian $
+ * @version $Revision: 1.7 $ $Date: 2005/03/30 14:15:42 $ $Author: christian $
  * @author Marcel Kiesling <makie2001@web.de>
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
@@ -31,16 +30,10 @@
 #ifndef SERVER_UDP_SOURCE
 #define SERVER_UDP_SOURCE
 
-#include <stdio.h>
-#include <sys/types.h>
-#include <sys/socket.h>
-#include <netinet/in.h>
-#include <arpa/inet.h>
-
+/*??
 char *pfad = "/home/cybop/object/socket/server_udp.o";
 
-int main()
-{
+int main() {
 
     int socketnummer;
     int laenge;
@@ -77,6 +70,7 @@ while (i<10) {
  close(socketnummer);
 return 0;
 }
+*/
 
 /* SERVER_UDP_SOURCE */
 #endif
