@@ -1,9 +1,8 @@
 /*
  * $RCSfile: unix_socket.c,v $
  *
- * Copyright (c) 1999-2005. Christian Heller. All rights reserved.
+ * Copyright (c) 1999-2005. Christian Heller and the CYBOP developers.
  *
- * This software is published under the GPL GNU General Public License.
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
  * as published by the Free Software Foundation; either version 2
@@ -21,7 +20,7 @@
  * http://www.cybop.net
  * - Cybernetics Oriented Programming -
  *
- * @version $Revision: 1.14 $ $Date: 2005/01/19 13:41:35 $ $Author: christian $
+ * @version $Revision: 1.17 $ $Date: 2005/06/05 11:12:18 $ $Author: christian $
  * @author Marcel Kiesling <makie2001@web.de>
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
@@ -31,10 +30,10 @@
 
 #include <sys/socket.h>
 #include <sys/un.h>
-#include "../accessor/compound_accessor.c"
-#include "../global/constant.c"
-#include "../global/integer_constants.c"
-#include "../global/variables.c"
+#include "../globals/constants/constant.c"
+#include "../globals/constants/integer_constants.c"
+#include "../globals/variables/variables.c"
+#include "../memory/accessor/compound_accessor.c"
 
 /**
  * Creates the unix server socket.
